import React, {Component} from "react";
import './ArticlesPage.css';
import {API_BASE_URL} from "../../config";
import {Header, Message} from "semantic-ui-react";
import ArticlesPageTable from "../../components/ArticlesPageTable/ArticlesPageTable";

export default class ArticlesPage extends Component {
    constructor(props) {
        super(props);
        this.state = {
            articles: null,
            isLoading: false
        }
    }

    async getArticles() {
        if (!this.state.articles) {
            try {
                this.setState({isLoading: true});
                const response = await fetch(
                    API_BASE_URL + '/articles',
                    {
                        headers: {
                            Accept: "application/json"
                        }
                    }
                )

                const articlesData = await response.json();
                this.setState({articles: articlesData.data, isLoading: false});
            } catch (e) {
                this.setState({isLoading: false});
                console.error(e);
            }
        }
    }

    componentDidMount() {
        this.getArticles();
    }

    render() {
        return (
            <div>
                <Header as="h1">Articles</Header>
                {this.state.isLoading && <Message info header="Loading articles..." />}
                {this.state.articles && <ArticlesPageTable articles={this.state.articles} />}
            </div>
        );
    }
}
